@@ -15,12 +15,11 @@ class Gremlin:
         "EntryType": lambda et: int(et)
     }
 
-    config = TurbindoConfiguration().config
-
     @classmethod
     @property
     def g(cls) -> GraphTraversalSource:
+        config = TurbindoConfiguration().config
         return traversal().withRemote(DriverRemoteConnection(
-            cls.config.db.gremlin.url,
-            cls.config.db.gremlin.traversal_source
+            config.db.gremlin.url,
+            config.db.gremlin.traversal_source
         ))
